@@ -66,7 +66,7 @@ Where the actual name to be substituted is, itself, a parameter.
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
